import os
import zipfile

CUR_DIR = os.path.dirname(os.path.realpath(__file__))

lang2treebank = {
    'afrikaans': 'UD_Afrikaans-AfriBooms',
    'ancient-greek': 'UD_Ancient_Greek-PROIEL',
    'arabic': 'UD_Arabic-PADT',
    'armenian': 'UD_Armenian-ArmTDP',
    'basque': 'UD_Basque-BDT',
    'belarusian': 'UD_Belarusian-HSE',
    'bulgarian': 'UD_Bulgarian-BTB',
    'catalan': 'UD_Catalan-AnCora',
    'chinese': 'UD_Simplified_Chinese-GSDSimp',
    'traditional-chinese': 'UD_Chinese-GSD',
    'classical-chinese': 'UD_Classical_Chinese-Kyoto',
    'croatian': 'UD_Croatian-SET',
    'czech': 'UD_Czech-PDT',
    'danish': 'UD_Danish-DDT',
    'dutch': 'UD_Dutch-Alpino',
    'english': 'UD_English-EWT',
    'estonian': 'UD_Estonian-EWT',
    'finnish': 'UD_Finnish-TDT',
    'french': 'UD_French-GSD',
    'galician': 'UD_Galician-CTG',
    'german': 'UD_German-GSD',
    'hebrew': 'UD_Hebrew-HTB',
    'hindi': 'UD_Hindi-HDTB',
    'hungarian': 'UD_Hungarian-Szeged',
    'indonesian': 'UD_Indonesian-GSD',
    'irish': 'UD_Irish-IDT',
    'italian': 'UD_Italian-ISDT',
    'japanese': 'UD_Japanese-GSD',
    'kazakh': 'UD_Kazakh-KTB',
    'korean': 'UD_Korean-GSD',
    'kurmanji': 'UD_Kurmanji-MG',
    'latin': 'UD_Latin-ITTB',
    'latvian': 'UD_Latvian-LVTB',
    'lithuanian': 'UD_Lithuanian-ALKSNIS',
    'marathi': 'UD_Marathi-UFAL',
    'bokmaal-norwegian': 'UD_Norwegian-Bokmaal',
    'nynorsk-norwegian': 'UD_Norwegian_Nynorsk-Nynorsk',
    'old-french': 'UD_Old_French-SRCMF',
    'old-russian': 'UD_Old_Russian-TOROT',
    'persian': 'UD_Persian-Seraji',
    'polish': 'UD_Polish-PDB',
    'portuguese': 'UD_Portuguese-Bosque',
    'romanian': 'UD_Romanian-RRT',
    'russian': 'UD_Russian-SynTagRus',
    'scottish-gaelic': 'UD_Scottish_Gaelic-ARCOSG',
    'serbian': 'UD_Serbian-SET',
    'slovak': 'UD_Slovak-SNK',
    'slovenian': 'UD_Slovenian-SSJ',
    'spanish': 'UD_Spanish-AnCora',
    'swedish': 'UD_Swedish-Talbanken',
    'tamil': 'UD_Tamil-TTB',
    'telugu': 'UD_Telugu-MTG',
    'turkish': 'UD_Turkish-IMST',
    'ukrainian': 'UD_Ukrainian-IU',
    'urdu': 'UD_Urdu-UDTB',
    'uyghur': 'UD_Uyghur-UDT',
    'vietnamese': 'UD_Vietnamese-VTB'
}

treebank2lang = {v: k for k, v in lang2treebank.items()}

tbname2training_id = {"UD_Afrikaans-AfriBooms": 2, "UD_Ancient_Greek-Perseus": 2, "UD_Ancient_Greek-PROIEL": 2,
                      "UD_Arabic-PADT": 1, "UD_Armenian-ArmTDP": 1, "UD_Basque-BDT": 2, "UD_Belarusian-HSE": 2,
                      "UD_Bulgarian-BTB": 2, "UD_Buryat-BDT": 4, "UD_Catalan-AnCora": 1, "UD_Chinese-GSD": 2,
                      "UD_Classical_Chinese-Kyoto": 2, "UD_Coptic-Scriptorium": 1, "UD_Croatian-SET": 2,
                      "UD_Czech-CAC": 1, "UD_Czech-CLTT": 1, "UD_Czech-FicTree": 1, "UD_Czech-PDT": 1,
                      "UD_Danish-DDT": 2, "UD_Dutch-Alpino": 2, "UD_Dutch-LassySmall": 2, "UD_English-EWT": 2,
                      "UD_English-GUM": 2, "UD_English-LinES": 2, "UD_English-ParTUT": 1, "UD_Estonian-EDT": 2,
                      "UD_Estonian-EWT": 4, "UD_Finnish-FTB": 1, "UD_Finnish-TDT": 1, "UD_French-GSD": 1,
                      "UD_French-ParTUT": 1, "UD_French-Sequoia": 1, "UD_French-Spoken": 1, "UD_Galician-CTG": 1,
                      "UD_Galician-TreeGal": 3, "UD_German-GSD": 1, "UD_German-HDT": 2, "UD_Gothic-PROIEL": 2,
                      "UD_Greek-GDT": 1, "UD_Hebrew-HTB": 1, "UD_Hindi-HDTB": 2, "UD_Hungarian-Szeged": 2,
                      "UD_Indonesian-GSD": 2, "UD_Irish-IDT": 2, "UD_Italian-ISDT": 1, "UD_Italian-ParTUT": 1,
                      "UD_Italian-PoSTWITA": 1, "UD_Italian-TWITTIRO": 1, "UD_Italian-VIT": 1, "UD_Japanese-GSD": 2,
                      "UD_Kazakh-KTB": 3, "UD_Korean-GSD": 2, "UD_Korean-Kaist": 2, "UD_Kurmanji-MG": 4,
                      "UD_Latin-ITTB": 2, "UD_Latin-Perseus": 4, "UD_Latin-PROIEL": 2, "UD_Latvian-LVTB": 2,
                      "UD_Lithuanian-ALKSNIS": 2, "UD_Lithuanian-HSE": 2, "UD_Livvi-KKPP": 4, "UD_Maltese-MUDT": 2,
                      "UD_Marathi-UFAL": 1, "UD_North_Sami-Giella": 4, "UD_Norwegian_Nynorsk-Nynorsk": 2,
                      "UD_Norwegian_Nynorsk-NynorskLIA": 2, "UD_Norwegian-Bokmaal": 2,
                      "UD_Old_Church_Slavonic-PROIEL": 2, "UD_Old_French-SRCMF": 2, "UD_Old_Russian-TOROT": 2,
                      "UD_Persian-Seraji": 1, "UD_Polish-LFG": 2, "UD_Polish-PDB": 1, "UD_Portuguese-Bosque": 1,
                      "UD_Portuguese-GSD": 1, "UD_Romanian-Nonstandard": 2, "UD_Romanian-RRT": 2, "UD_Russian-GSD": 2,
                      "UD_Russian-SynTagRus": 2, "UD_Russian-Taiga": 2, "UD_Scottish_Gaelic-ARCOSG": 1,
                      "UD_Serbian-SET": 2, "UD_Simplified_Chinese-GSDSimp": 2, "UD_Slovak-SNK": 2,
                      "UD_Slovenian-SSJ": 2, "UD_Slovenian-SST": 4, "UD_Spanish-AnCora": 1, "UD_Spanish-GSD": 1,
                      "UD_Swedish_Sign_Language-SSLC": 2, "UD_Swedish-LinES": 2, "UD_Swedish-Talbanken": 2,
                      "UD_Tamil-TTB": 1, "UD_Telugu-MTG": 2, "UD_Turkish-IMST": 1, "UD_Ukrainian-IU": 1,
                      "UD_Upper_Sorbian-UFAL": 4, "UD_Urdu-UDTB": 2, "UD_Uyghur-UDT": 2, "UD_Vietnamese-VTB": 2,
                      "UD_Wolof-WTB": 1}

tbname2shorthand = {
    'UD_Arabic-PADT': 'ar_padt',
    'UD_French-GSD': 'fr_gsd',
    'UD_Spanish-AnCora': 'es_ancora',
    'UD_Chinese-GSD': 'zh_gsd',
    'UD_English-EWT': 'en_ewt',
    'UD_Afrikaans-AfriBooms': 'af_afribooms',
    'UD_Ancient_Greek-Perseus': 'grc_perseus',
    'UD_Ancient_Greek-PROIEL': 'grc_proiel',
    'UD_Armenian-ArmTDP': 'hy_armtdp',
    'UD_Basque-BDT': 'eu_bdt',
    'UD_Belarusian-HSE': 'be_hse',
    'UD_Bulgarian-BTB': 'bg_btb',
    'UD_Catalan-AnCora': 'ca_ancora',
    'UD_Classical_Chinese-Kyoto': 'lzh_kyoto',
    'UD_Croatian-SET': 'hr_set',
    'UD_Czech-CAC': 'cs_cac',
    'UD_Czech-CLTT': 'cs_cltt',
    'UD_Czech-FicTree': 'cs_fictree',
    'UD_Czech-PDT': 'cs_pdt',
    'UD_Danish-DDT': 'da_ddt',
    'UD_Dutch-Alpino': 'nl_alpino',
    'UD_Dutch-LassySmall': 'nl_lassysmall',
    'UD_English-GUM': 'en_gum',
    'UD_English-LinES': 'en_lines',
    'UD_English-ParTUT': 'en_partut',
    'UD_Estonian-EDT': 'et_edt',
    'UD_Estonian-EWT': 'et_ewt',
    'UD_Estonian-EWT2': 'et_ewt2',
    'UD_Finnish-FTB': 'fi_ftb',
    'UD_Finnish-TDT': 'fi_tdt',
    'UD_French-ParTUT': 'fr_partut',
    'UD_French-Sequoia': 'fr_sequoia',
    'UD_French-Spoken': 'fr_spoken',
    'UD_Galician-CTG': 'gl_ctg',
    'UD_Galician-TreeGal': 'gl_treegal',
    'UD_Galician-TreeGal2': 'gl_treegal2',
    'UD_German-GSD': 'de_gsd',
    'UD_German-HDT': 'de_hdt',
    'UD_Greek-GDT': 'el_gdt',
    'UD_Hebrew-HTB': 'he_htb',
    'UD_Hindi-HDTB': 'hi_hdtb',
    'UD_Hungarian-Szeged': 'hu_szeged',
    'UD_Indonesian-GSD': 'id_gsd',
    'UD_Irish-IDT': 'ga_idt',
    'UD_Italian-ISDT': 'it_isdt',
    'UD_Italian-ParTUT': 'it_partut',
    'UD_Italian-PoSTWITA': 'it_postwita',
    'UD_Italian-TWITTIRO': 'it_twittiro',
    'UD_Italian-VIT': 'it_vit',
    'UD_Japanese-GSD': 'ja_gsd',
    'UD_Kazakh-KTB': 'kk_ktb',
    'UD_Kazakh-KTB2': 'kk_ktb2',
    'UD_Korean-GSD': 'ko_gsd',
    'UD_Korean-Kaist': 'ko_kaist',
    'UD_Kurmanji-MG': 'kmr_mg',
    'UD_Kurmanji-MG2': 'kmr_mg2',
    'UD_Latin-ITTB': 'la_ittb',
    'UD_Latin-Perseus': 'la_perseus',
    'UD_Latin-Perseus2': 'la_perseus2',
    'UD_Latin-PROIEL': 'la_proiel',
    'UD_Latvian-LVTB': 'lv_lvtb',
    'UD_Lithuanian-ALKSNIS': 'lt_alksnis',
    'UD_Lithuanian-HSE': 'lt_hse',
    'UD_Livvi-KKPP': 'olo_kkpp',
    'UD_Maltese-MUDT': 'mt_mudt',
    'UD_Marathi-UFAL': 'mr_ufal',
    'UD_North_Sami-Giella': 'sme_giella',
    'UD_Norwegian_Nynorsk-Nynorsk': 'no_nynorsk',
    'UD_Norwegian_Nynorsk-NynorskLIA': 'no_nynorsklia',
    'UD_Norwegian-Bokmaal': 'no_bokmaal',
    'UD_Old_Church_Slavonic-PROIEL': 'cu_proiel',
    'UD_Old_French-SRCMF': 'fro_srcmf',
    'UD_Old_Russian-TOROT': 'orv_torot',
    'UD_Persian-Seraji': 'fa_seraji',
    'UD_Polish-LFG': 'pl_lfg',
    'UD_Polish-PDB': 'pl_pdb',
    'UD_Portuguese-Bosque': 'pt_bosque',
    'UD_Portuguese-GSD': 'pt_gsd',
    'UD_Romanian-Nonstandard': 'ro_nonstandard',
    'UD_Romanian-RRT': 'ro_rrt',
    'UD_Russian-GSD': 'ru_gsd',
    'UD_Russian-SynTagRus': 'ru_syntagrus',
    'UD_Russian-Taiga': 'ru_taiga',
    'UD_Scottish_Gaelic-ARCOSG': 'gd_arcosg',
    'UD_Serbian-SET': 'sr_set',
    'UD_Simplified_Chinese-GSDSimp': 'zh_gsdsimp',
    'UD_Slovak-SNK': 'sk_snk',
    'UD_Slovenian-SSJ': 'sl_ssj',
    'UD_Slovenian-SST': 'sl_sst',
    'UD_Slovenian-SST2': 'sl_sst2',
    'UD_Spanish-GSD': 'es_gsd',
    'UD_Swedish_Sign_Language-SSLC': 'swl_sslc',
    'UD_Swedish-LinES': 'sv_lines',
    'UD_Swedish-Talbanken': 'sv_talbanken',
    'UD_Tamil-TTB': 'ta_ttb',
    'UD_Telugu-MTG': 'te_mtg',
    'UD_Turkish-IMST': 'tr_imst',
    'UD_Ukrainian-IU': 'uk_iu',
    'UD_Upper_Sorbian-UFAL': 'hsb_ufal',
    'UD_Urdu-UDTB': 'ur_udtb',
    'UD_Uyghur-UDT': 'ug_udt',
    'UD_Vietnamese-VTB': 'vi_vtb',
    'UD_Wolof-WTB': 'wo_wtb'
}
